summaryrefslogtreecommitdiffstats
path: root/kplato/kptresourceview.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kplato/kptresourceview.cc
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kplato/kptresourceview.cc')
-rw-r--r--kplato/kptresourceview.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kplato/kptresourceview.cc b/kplato/kptresourceview.cc
index 58ea413e..d596ff44 100644
--- a/kplato/kptresourceview.cc
+++ b/kplato/kptresourceview.cc
@@ -203,7 +203,7 @@ protected:
c = fc;
// draw to last interesting column
- const TQColorGroup &cg = ( palette().inactive() );
+ const TQColorGroup &cg = ( tqpalette().inactive() );
while ( c < lc && !drawables.isEmpty() ) {
int i = header()->mapToLogical( c );
@@ -240,7 +240,7 @@ protected:
if ( tx < 0 )
tx = header()->cellPos( cell );
- // do any children of current need to be painted?
+ // do any tqchildren of current need to be painted?
/* FIXME: painting branches doesn't work for some reason...
if ( ih != ith &&
rootIsDecorated() &&
@@ -268,7 +268,7 @@ protected:
p->translate( rleft, crtop );
//kdDebug()<<k_funcinfo<<"paintBranches: "<<current->i->text(0)<<endl;
- current->i->paintBranches( p, colorGroup(), treeStepSize(),
+ current->i->paintBranches( p, tqcolorGroup(), treeStepSize(),
rtop - crtop, r.height() );
p->restore();
}
@@ -362,8 +362,8 @@ public:
TQDate date;
};
-TQSize ResourceView::sizeHint() const {
- return minimumSizeHint(); // HACK: koshell splitter minimumSize problem
+TQSize ResourceView::tqsizeHint() const {
+ return tqminimumSizeHint(); // HACK: koshell splitter tqminimumSize problem
}
ResourceView::ResourceView(View *view, TQWidget *parent)